#
# spec file for package python-jupyter-ydoc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-jupyter-ydoc
Version:        2.1.1
Release:        1.1
Summary:        Document structures for collaborative editing using Ypy
License:        BSD-3-Clause
URL:            https://github.com/jupyter-server/jupyter_ydoc
# Versioned sdist
Source0:        https://files.pythonhosted.org/packages/source/j/jupyter-ydoc/jupyter_ydoc-%{version}.tar.gz
# unversioned, but tests
Source1:        https://github.com/jupyter-server/jupyter_ydoc/archive/refs/tags/v%{version}.tar.gz#/jupyter_ydoc-%{version}-gh.tar.gz
Source2:        node_modules.tar.xz
# Execute this on every package update. See comments in the script.
Source3:        create_node_modules.sh
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module hatch_nodejs_version}
BuildRequires:  %{python_module hatchling >= 1.10}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       (python-importlib-metadata >= 3.6 if python-base < 3.10)
Requires:       (python-pycrdt >= 0.9 with python-pycrdt < 0.10)
Provides:       python-jupyter_ydoc = %{version}-%{release}
BuildArch:      noarch
# SECTION test
BuildRequires:  %{python_module importlib-metadata >= 3.6 if %python-base < 3.10}
BuildRequires:  %{python_module pycrdt >= 0.9 with %python-pycrdt < 0.10}
BuildRequires:  %{python_module pycrdt-websocket >= 0.14.1 with %python-pycrdt-websocket < 0.15}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module websockets >= 10.0}
BuildRequires:  nodejs
BuildRequires:  procps
BuildRequires:  yarn
# /SECTION
%python_subpackages

%description
Ypy-based data structures for various documents used in the Jupyter ecosystem.
Built-in documents include:
  - `YBlob`: a generic immutable binary document.
  - `YUnicode`: a generic UTF8-encoded text document (`YFile` is an alias to `YUnicode`).
  - `YNotebook`: a Jupyter notebook document.

%prep
%setup -q -n jupyter_ydoc-%{version} -b1 -a2

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# https://github.com/jupyter-server/jupyter_ydoc/issues/168
%pytest -v && pkill -f yjs_client_0.js -e

%files %{python_files}
%{python_sitelib}/jupyter_ydoc
%{python_sitelib}/jupyter_ydoc-%{version}.dist-info

%changelog
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.1.1
  * Fix dict type for python 3.8 #252 (@davidbrochart)
  * Add undo_manager to Y documents (#248) #251 (@davidbrochart)
* Mon Jan 22 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.0.1
  * Update pycrdt v0.8 #208 (@davidbrochart)
- Release 2.0.0
  * Use pycrdt instead of y-py #194 (@davidbrochart)
- Ignore that pycrdt is still in incubation phase
  gh#jupyter-server/jupyter_ydoc#211
* Sun Jan 21 2024 Ben Greiner <code@bnavigator.de>
- Disable tests for jupyter-collaboration and ypy-websocket
  update gh#jupyter-server/jupyter_ydoc#211
* Sat Oct  7 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.1.1
  * Fix joining of source when source is an array of strings #186
    (@jtpio)
* Sun Sep 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.1.0
  * Add source to dist for sourcemaps #182 (@vidartf)
  * Create awareness interface #171 (@hbcarlos)
* Tue Jun 13 2023 Ben Greiner <code@bnavigator.de>
- Kill nodejs in between pytest runs
  gh#jupyter-server/jupyter_ydoc#168
* Sun Jun 11 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.0.2
  * Trust the default cell #161 (@krassowski)
- Releases 1.0.0, 1.0.1
  * Fix metadata issue #158 (@hbcarlos)
  * Add py.typed #152 (@davidbrochart)
  * Add model version #139 (@davidbrochart)
- Release 0.3.x
  * Fix notebook undo scope #148 (@fcollonval)
  * Update YDocument constructor #142 (@trungleduc)
  * Add ycells getter #136 (@davidbrochart)
  * Split documents into separate files #135 (@davidbrochart)
  * Fixes handling metadata changes #134 (@hbcarlos)
  * Improves the initialization #124 (@hbcarlos)
  * Improve Python API #122 (@davidbrochart)
  * Notebook metadata #115 (@hbcarlos)
  * Make YDocument a IObservableDisposable #108 (@fcollonval)
  * Add readme to javascript package #106 (@fcollonval)
  * Adds docstring to the python package #101 (@hbcarlos)
  * Import shared model #86 (@fcollonval)
  * Add path document attribute #81 (@davidbrochart)
  * Make YBaseDoc an abstract base class #74 (@davidbrochart)
  * Fixes multiple bugs #131 (@hbcarlos)
  * Fixes metadata #120 (@hbcarlos)
  * Support cell.source is [list, of, string] #112 (@Wh1isper)
  * Removes YMap for attachements #77 (@fcollonval)
  * Drop pkg_resources #59 (@jtpio)
  * Remove factory API #133 (@hbcarlos)
  * Import shared model #86 (@fcollonval)
* Mon Apr 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.2.4
  * Fix metadata issue #158 (@hbcarlos)
* Sun Mar 19 2023 Ben Greiner <code@bnavigator.de>
- Downgrade to 0.2.3
  * Rename JS package to @jupyter/ydoc #97 (@jtpio)
- Released as patch release for 0.2 branch
  * jupyterlab 3.6 requires ydoc~=0.2.2
* Sun Feb 12 2023 Ben Greiner <code@bnavigator.de>
- Provide underscore name
* Sun Feb  5 2023 Ben Greiner <code@bnavigator.de>
- Initial specfile for v0.3.1
- Required by jupyterlab 3.6
- Provide node_modules.tar.xz generated by create_node_modules.sh
  for the tests. Those modules are not part of the python package
